/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh;

import org.eclipse.core.resources.IResource;

/**
 * An <code>IMonitorFactory</code> is responsible for 
 * creating <code>IMonitor</code> objects.  The factory must
 * decide if the <code>IMonitor</code> it creates is capable 
 * of monitoring the file, or folder and subtree under of path 
 * that is given.
 * <p>
 * WARNING:  This is experimental API.  It is likely to change in future releases.
 */
public interface IMonitorFactory {
	/**
	 * Answers a <code>IMonitor</code> which will monitor the given resource. If
	 * the resource is an <code>IContainer</code> the monitor will also
	 * monitor the subtree under the container. Answers <code>null</code> if
	 * this factory cannot create a monitor for the given container.
	 * 
	 * @param resource		The resource to monitor, always non-<code>null</code>.
	 * @return IMonitor	A monitor on the resource, or <code>null</code>
	 * 						if the given resource cannot be monitored by
	 * 						the monitor that this factory creates.
	 */
	IMonitor createMonitor(IResource resource);
}
