/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh;

import java.util.Map;

import org.eclipse.core.resources.IResource;

/**
 * Clients should implement the <code>IRefreshRequest</code> interface
 * in order to make refresh requests to the <code>AutoRefreshPlugin</code>.
 * <p>
 * WARNING:  This is experimental API.  It is likely to change in future releases.
 * 
 * @see com.example.autorefresh.SimpleRefreshRequest
 * @see com.example.autorefresh.AutoRefreshPlugin.refresh(IRefreshRequest)
 */
public interface IRefreshRequest {
	/**
	 * Answers <code>true</code> if and only if this request does
	 * not contain any additions, deletions, changes or transforms.
	 */
	boolean isEmpty();
	/**
	 * Answers <code>true</code> if this request contains information
	 * about files or folders which were added.
	 */
	boolean hasAdditions();
	/**
	 * Answers a mapping of existing <code>IContainer</code> files
	 * to collections of simple names of resources which have been
	 * added.
	 * @return Map	The resource mapping, or <code>null</code>
	 * 				if no resources were added.
	 */
	Map getAdditions();
	/**
	 * Answers <code>true</code> if this request contains information
	 * about files or folders which were deleted.
	 */
	boolean hasDeletions();
	/**
	 * Answers an array of resources which were deleted.
	 * @return IResource[]	The resources which were deleted, or <code>null</code>
	 * 						if no resources were deleted.
	 */
	IResource[] getDeletions();
	/**
	 * Answers <code>true</code> if this request contains information
	 * about files or folders which were changed.
	 */
	boolean hasChanges();

	/**
	 * Answers an array of resources which were changed.
	 * @return IResource[]	The resources which were changed, or <code>null</code>
	 * 						if no resource changes were detected.
	 */
	IResource[] getChanges();
	/**
	 * Answers <code>true</code> if this request contains information
	 * about files or folders which were transformed (i.e. changed from
	 * file to folder or from folder to file).
	 */	
	boolean hasTransforms();
	/**
	 * Answers an array of resources which were transformed.  For
	 * example if a file becomes a folder, it is considered to be a
	 * transform.
	 * @return IResource[]	The resources which were transformed, or <code>null</code>
	 * 						if no resource transforms were detected.
	 */
	IResource[] getTransforms();
}
