/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh.linux;

/**
 * Native callback example, used during development as a simple test.
 * To run, specify directories to be monitored as arguments.  When you
 * are done testing, press enter in the console to stop the program.
 */
public class Example {

	public static void main(String[] args) throws Exception {
		Monitor monitor = new Monitor(new IMonitorListener() {
			public void fileCreated (String path) {
				System.out.println (path + " created (file)");
			}
			public void fileDeleted (String path) {
				System.out.println (path + " deleted");
			}
			public void fileChanged (String path) {
				System.out.println (path + " changed");
			}
			public void directoryCreated (String path) {
				System.out.println (path + " created (directory)");
			}
		});
		for (int i = 0; i < args.length; i++) {
			monitor.addPath(args[i]);
			System.out.println ("Monitoring " + args[i]);
		}
		new Thread(monitor).start();
		System.out.println("Press 'Enter' to quit");
		System.in.read();
		for (int i = 0; i < args.length; i++) {
			monitor.removePath(args[i]);
		}
		monitor.done();
	}
}