/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh.linux;

/**
 * Clients may implement this interface and register
 * it with the <code>Monitor</code> class to recieve notification
 * of file changes.
 */
public interface IMonitorListener {
	/**
	 * Notifies this listener that a file was created.
	 * 
	 * @param path	The location of the file which was created.
	 */
	public void fileCreated (String path);
	/**
	 * Notifies this listener that a file was deleted.
	 * 
	 * @param path The location of the file which was deleted.
	 */
	public void fileDeleted (String path);
	/**
	 * Notifies the listener that a file changed.
	 * 
	 * @param path The location of the file which changed.
	 */
	public void fileChanged (String path);
	
	/**
	 * Notifies the listener that a directory was created
	 * 
	 * @param path The location of the directory which was created
	 */
	public void directoryCreated (String path);
}