/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh.linux;

import com.example.autorefresh.AutoRefreshPlugin;

/**
 * 
 */
public class LinuxNatives {
	
	/*
	 * Loads the native library.
	 */
	static {
		if (AutoRefreshPlugin.getDefault().isDebugging()) {
			System.out.println ("Loading native library");
		}
		System.loadLibrary("refresh"); //$NON-NLS-1$
		if (AutoRefreshPlugin.getDefault().isDebugging()) {
			System.out.println ("Success!");
		}
	}
	
	/**
	 * Used for debugging from within the natives.
	 * 
	 * @param string A message.
	 */
	public static void PrintString (String string) {
		System.out.print (string);
	}
	
	/**
	 * Instructs the natives to add a new directory to the list to be monitored.
	 * 
	 * @param path Location of a directory to monitor
	 * @return a handle to the directory monitor to be used in RemoveMonitor(), or 0
	 * if adding the monitor failed
	 */
	public static native int AddDirectoryMonitor (String path);
	
	/**
	 * Inform the natives to stop monitoring the directory denoted by the monitor_handle.
	 * 
	 * @param monitor_handle the handle of the monitor created from AddDirectoryMonitor()
	 * @return boolean true if monitoring was stopped, else false
	 */
	public static native boolean RemoveMonitor (int monitor_handle);

	/**
	 * Blocks waiting for the next filesystem event to be generated by the native monitor.
	 * 
	 * @return MonitorEvent
	 */
	public static native MonitorEvent GetNextEvent ();
}
