/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh.linux;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IPath;

import com.example.autorefresh.IMonitor;
import com.example.autorefresh.IMonitorFactory;

public class MonitorFactory implements IMonitorFactory {

	private Monitor monitor;
	
	public IMonitor createMonitor(IResource resource) {
		IPath path= resource.getLocation();
		if (path == null || !resource.exists()) {
			return null;
		}
		
		if (resource.getType() == IResource.FILE) {
			return null;
		}

		// Singleton, create the Monitor if it doesn't already exist
		synchronized (this) {
			if (monitor == null) {
				monitor = new Monitor(new MonitorListener());
			}
		}
		
		// A path must be added before starting the thread
		if (!monitor.addPath(path.toOSString())) {
			// Failed to add a monitor for this path
			return null;
		}

		// Now we can start the thread running if its not already
		if (!monitor.running) {
			new Thread(monitor).start();
		}
		
		return monitor;
	}
	

}
