/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh.ui.internal;

import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.jface.preference.IntegerFieldEditor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import com.example.autorefresh.AutoRefreshPlugin;

/**
 * A page to set the preferences for the console
 */
public class AutoRefreshPreferencePage extends FieldEditorPreferencePage implements IWorkbenchPreferencePage {
	
	private BooleanFieldEditor2 fAutoPoll= null;
	private BooleanFieldEditor2 fAutoRefresh= null;
	private IntegerFieldEditor fRefreshDelay= null;
	private IntegerFieldEditor fPollDelay= null;
	/**
	 * Create the console page.
	 */
	public AutoRefreshPreferencePage() {
		super(GRID);
		setDescription("Controls how the workbench handles changes in the file system.");
		setPreferenceStore(AutorefreshUIPlugin.getDefault().getPreferenceStore());
	}

	/**
	 * @see PreferencePage#createControl(Composite)
	 */
	public void createControl(Composite parent) {
		super.createControl(parent);
//		WorkbenchHelp.setHelp(
//			parent,
//			 );
	}
	
	/**
	 * Create all field editors for this page
	 */
	public void createFieldEditors() {
		fAutoRefresh= new BooleanFieldEditor2(AutoRefreshPlugin.PREF_AUTO_REFRESH, "Update workbench with file system changes automatically", SWT.NONE, getFieldEditorParent());
		addField(fAutoRefresh);
		
		fRefreshDelay = new IntegerFieldEditor(AutoRefreshPlugin.PREF_AUTO_REFRESH_DELAY, "Delay between updates (ms)", getFieldEditorParent());
		addField(fRefreshDelay);
		fRefreshDelay.setValidRange(1, Integer.MAX_VALUE);		

		fAutoRefresh.getChangeControl(getFieldEditorParent()).addSelectionListener(
			new SelectionAdapter() {
				public void widgetSelected(SelectionEvent e) {
					updateAutoRefreshDelayEditor();
				}
			}
		);		
		
		fAutoPoll = new BooleanFieldEditor2(AutoRefreshPlugin.PREF_AUTO_POLL, "Poll the file system for out of synch resources when native support fails", SWT.NONE, getFieldEditorParent());
		addField(fAutoPoll);		

		fPollDelay= new IntegerFieldEditor(AutoRefreshPlugin.PREF_AUTO_POLL_DELAY, "Delay between polls (ms)", getFieldEditorParent());
		addField(fPollDelay);
		fPollDelay.setValidRange(1, Integer.MAX_VALUE);

		fAutoPoll.getChangeControl(getFieldEditorParent()).addSelectionListener(
			new SelectionAdapter() {
				public void widgetSelected(SelectionEvent e) {
					updateAutoPollDelayEditor();
				}
			}
		);
	}

	/**
	 * @see IWorkbenchPreferencePage#init(IWorkbench)
	 */
	public void init(IWorkbench workbench) {
	}

	/**
	 * @see IPreferencePage#performOk()
	 */
	public boolean performOk() {
		boolean ok= super.performOk();
		AutoRefreshPlugin.getDefault().savePluginPreferences();
		return ok;
	}

	/**
	 * @see org.eclipse.jface.preference.FieldEditorPreferencePage#initialize()
	 */
	protected void initialize() {
		super.initialize();
		updateAutoRefreshDelayEditor();
		updateAutoPollDelayEditor();
	}
	
	/**
	 * Update enablement of auto refresh delay editor which is based off of the
	 * enablement of the auto refresh preference.
	 */
	protected void updateAutoRefreshDelayEditor() {
		Button b = fAutoRefresh.getChangeControl(getFieldEditorParent());
		fRefreshDelay.getTextControl(getFieldEditorParent()).setEnabled(b.getSelection());
		fRefreshDelay.getLabelControl(getFieldEditorParent()).setEnabled(b.getSelection());				
	}

	/**
	 * Update enablement of auto poll delay editor which is based off of the enablement
	 * of the auto poll preference.
	 */
	protected void updateAutoPollDelayEditor() {
		Button b = fAutoPoll.getChangeControl(getFieldEditorParent());
		fPollDelay.getTextControl(getFieldEditorParent()).setEnabled(b.getSelection());
		fPollDelay.getLabelControl(getFieldEditorParent()).setEnabled(b.getSelection());
	}

	/**
	 * @see org.eclipse.jface.preference.PreferencePage#performDefaults()
	 */
	protected void performDefaults() {
		super.performDefaults();
		updateAutoRefreshDelayEditor();
		updateAutoPollDelayEditor();
	}
}