/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh.ui.internal;

import org.eclipse.core.runtime.Preferences;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;

import com.example.autorefresh.AutoRefreshPlugin;

public abstract class AutorefreshActionDelegate implements IWorkbenchWindowActionDelegate {

	/**
	 * The action this is a delegate to.
	 */
	protected IAction fAction;	

	/**
	 * The window this delegate was created in.
	 */
	protected IWorkbenchWindow fWindow;
	
	/**
	 * Property change listener to see if this action should
	 * be active.
	 */
	protected Preferences.IPropertyChangeListener fListener;

	/**
	 * @see IWorkbenchWindowActionDelegate#init(IWorkbenchWindow)
	 */
	public void init(IWorkbenchWindow window) {
		fWindow= window;
		addPropertyListener();
		setVisible(checkVisible());
	}

	/**
	 * @see IActionDelegate#selectionChanged(IAction, ISelection)
	 */	
	public void selectionChanged(IAction action, ISelection selection) {
		fAction= action;
	}


	/**
	 * @see IWorkbenchWindowActionDelegate#dispose()
	 */
	public void dispose() {
		removePropertyListener();
		fWindow= null;
		fAction= null;
	}

	public void setVisible(boolean visible) {
		setEnabled(fAction, visible);
	}
	

	public void setEnabled(final IAction action, final boolean enabled) {
		asynchExec(new Runnable() {
			public void run() {
				if (fAction != null) {
					fAction.setEnabled(enabled);
				}
			}
		});
	}
	
	public void asynchExec(Runnable r) {
		if (fWindow != null) {
			Shell shell= fWindow.getShell();
			if (shell != null) {
				Display display= shell.getDisplay();
				if (display != null && !display.isDisposed()) {
					display.asyncExec(r);
				}
			}
		}
	}				

	protected abstract Preferences.IPropertyChangeListener createPropertyChangeListener();
	protected abstract boolean checkVisible();
	
	private void addPropertyListener() {
		fListener= createPropertyChangeListener();
		Preferences preferences= AutoRefreshPlugin.getDefault().getPluginPreferences();
		if (preferences != null) {
			preferences.addPropertyChangeListener(fListener);
		}
	}

	private void removePropertyListener() {
		Preferences preferences= AutoRefreshPlugin.getDefault().getPluginPreferences();
		if (preferences != null) {
			preferences.removePropertyChangeListener(fListener);
		}
		fListener= null;
	}
}
