/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh.ui.internal;

import org.eclipse.core.runtime.Preferences;
import org.eclipse.core.runtime.Preferences.PropertyChangeEvent;
import org.eclipse.jface.action.IAction;

import com.example.autorefresh.AutoRefreshPlugin;

/**
 * The <code>SearchActionDelegate</code> provides the user with a simple
 * way to start the <code>AutoRefreshPlugin</code> and also to make requests
 * to search the contents of the workspace for resources that are out of synch.
 */
public class PollActionDelegate extends AutorefreshActionDelegate {
	/**
	 * Requests a polling of the filesystem.
	 * 
	 * @see IActionDelegate#run(IAction)
	 */
	public void run(final IAction action) {
		new Thread(new Runnable() {
			public void run() {
				setEnabled(action, false);		
				AutoRefreshPlugin.getDefault().poll();
				setEnabled(action, true);				
			}
		}, "poll request").start();
	}

	/*
	 * @see com.example.autorefresh.ui.internal.AutorefreshActionDelegate#createPropertyChangeListener()
	 */
	protected Preferences.IPropertyChangeListener createPropertyChangeListener() {
		return new Preferences.IPropertyChangeListener() {
			public void propertyChange(PropertyChangeEvent event) {
				String property= event.getProperty();
				if (AutoRefreshPlugin.PREF_AUTO_POLL.equals(property)) {
					boolean autoPoll= ((Boolean)event.getNewValue()).booleanValue();
					setVisible(!autoPoll);
				}
			}
		};
	}
	/*
	 * @see com.example.autorefresh.ui.internal.AutorefreshActionDelegate#checkVisible()
	 */
	protected boolean checkVisible() {
		Preferences preferences= AutoRefreshPlugin.getDefault().getPluginPreferences();
		if (preferences != null) {
			return !preferences.getBoolean(AutoRefreshPlugin.PREF_AUTO_POLL);
		}
		return false;
	}

}



