/*
 * Copyright (c) 2002 IBM Corp.  All rights reserved.
 * This file is made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package com.example.autorefresh.ui.internal;

import org.eclipse.core.runtime.Preferences;
import org.eclipse.core.runtime.Preferences.PropertyChangeEvent;
import org.eclipse.jface.action.IAction;

import com.example.autorefresh.AutoRefreshPlugin;

/**
 * The <code>RefreshActionDelegate</code> provides the user with a way to 
 * start a background refresh of the resources found during filesystem monitoring.  
 * This is only applicable when auto.refresh is <code>false</code> in the 
 * <code>AutoRefreshPlugin</code>.
 * 
 * @see AutoRefreshPlugin
 */
public class RefreshActionDelegate extends AutorefreshActionDelegate {
	/**
	 * Starts the refresh in the background.
	 * 
	 * @see IActionDelegate#run(IAction)
	 */
	public void run(final IAction action) {
		Runnable r= new Runnable() {
			public void run() {
				setEnabled(action, false);
				AutoRefreshPlugin.getDefault().refresh(null);
				setEnabled(action, true);
			}
		};
		new Thread(r, "refresh request").start();
	}

	/*
	 * @see com.example.autorefresh.ui.internal.AutorefreshActionDelegate#createPropertyChangeListener()
	 */
	protected Preferences.IPropertyChangeListener createPropertyChangeListener() {
		return new Preferences.IPropertyChangeListener() {
			public void propertyChange(PropertyChangeEvent event) {
				String property= event.getProperty();
				if (AutoRefreshPlugin.PREF_AUTO_REFRESH.equals(property)) {
					boolean autoRefresh= ((Boolean)event.getNewValue()).booleanValue();
					setVisible(!autoRefresh);
				}
			}
		};
	}

	/*
	 * @see com.example.autorefresh.ui.internal.AutorefreshActionDelegate#checkVisible()
	 */
	protected boolean checkVisible() {
		Preferences preferences= AutoRefreshPlugin.getDefault().getPluginPreferences();
		if (preferences != null) {
			return !preferences.getBoolean(AutoRefreshPlugin.PREF_AUTO_REFRESH);
		}
		return false;
	}
}