package com.example.autorefresh.win32.internal;

/**
 * The <code>IMonitorListener</code> is the the callback
 * mechanism through which the Win32 monitors notify registered
 * parties of changes.
 */
public interface IMonitorListener {

	/**
	 * Depth constant (value 0) indicating this resource should be
	 * refreshed, but not any of its members.
	 */
	int DEPTH_ZERO = 0;

	/**
	 * Depth constant (value 1) indicating this resource and its 
	 * direct members should be refreshed, but not its indirect members.
	 */
	int DEPTH_ONE = 1;

	/**
	 * Depth constant (value 2) indicating this resource and its 
	 * direct and indirect members at any depth should be refreshed.
	 */
	int DEPTH_INFINITE = 2;

	/**
	 * Requests that this listener perform a refresh on the resource
	 * at the given path to the given depth.
	 * 
	 * @param path		The absolute path to the changed resource, can 
	 * 					not be <code>null</code>.
	 * @param depth	The depth to which the resource should be refreshed,
	 * 					one of DEPTH_ZERO, DEPTH_ONE, DEPTH_INFINITE.
	 */
	void refresh(String path, int depth);
	
	/**
	 * Informs this listener that an error has occured.
	 * 
	 * @param throwable	A throwable, can be <code>null</code>.
	 * @param message		A message describing the error, or <code>null</code>.
	 */
	void logError(Throwable throwable, String message);
}