package com.example.autorefresh.win32.internal;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IPath;

import com.example.autorefresh.IMonitor;
import com.example.autorefresh.IMonitorFactory;

/**
 * The <code>MonitorFactory</code> creates monitors that 
 * can monitor drives on Win32 platforms.
 * 
 * @see com.example.autorefresh.IMonitorFactory
 */
public class MonitorFactory implements IMonitorFactory {
	/*
	 * The singleton monitor 
	 */
	private Win32Monitor fMonitor;
		
	/**
	 * Creates a standard Win32 monitor if the given container
	 * is local.
	 * 
	 * @see com.example.autorefresh.IMonitorFactory#createMonitor(IContainer)
	 */
	public IMonitor createMonitor(IResource resource) {

		IPath path= resource.getLocation();
		if (path == null) {
			return null;
		}
		
		if (!resource.exists()) {
			return null;
		}
		
		if (resource.getType() == IResource.FILE) {
			return null;
		}
				
		synchronized (this) {
			if (fMonitor == null) {
				fMonitor = new Win32Monitor(new MonitorListener());
			}
		}
					
		if (fMonitor.addResource(resource)) {
			return fMonitor;
		} else {
			return null;
		}
	}
}
